<template>
  <el-dialog
    width="60%"
    title="报工产出列表"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="part-dialog"
  >
    <ttable
      :table="table"
      @currentChange="handleCurrentChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :bottomOffset="350"
      :ajaxFun="ajaxFun"
      :paramObj="paramObj"
      ref="commonProductoutputTable"
    >
      <template #toolbar></template>
    </ttable>

    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
  </el-dialog>
</template>
<script>
import ttable from '@/views/common/ztt-table'
import { fetchOutputList } from '@/api/quality/apply'

export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    paramObj: {
      type: Object,
      default: () => {
        return {}
      }
    },
    outBatchNo: {
      type: String,
      default: () => {
        return null
      }
    }
  },
  data() {
    return {
      ajaxFun: fetchOutputList,
      innerVisible: false,
      listLoading: true,
      currentRow: null,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'commonProductoutput',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        cancelRunCreated: true,
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '160',
            prop: 'optaskNo',
            label: '工单号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '160',
            prop: 'systemNo',
            label: '系统编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '160',
            prop: 'outBatchNo',
            label: '零件批号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '160',
            prop: 'partNo',
            label: '零件编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '160',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'productQty',
            label: '生产数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '80',
            prop: 'unit',
            label: '单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'checkStatus',
            label: '检测状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: (row, column, cellValue) => {
              for (
                let i = 0, len = this.checkStatusOptions.length;
                i < len;
                i++
              ) {
                if (cellValue === this.checkStatusOptions[i].value) {
                  return this.checkStatusOptions[i].label
                }
              }
            },
            optList: () => {
              return this.checkStatusOptions
            }
          },
          {
            minWidth: '140',
            prop: 'isQualified',
            label: '检测是否合格',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: (row, column, cellValue) => {
              var formatVal
              if (cellValue && cellValue == true) {
                formatVal = '<span>是</span>'
              } else if (cellValue == false) {
                formatVal = '<span style="color:red">否</span>'
              } else {
                formatVal = '<span></span>'
              }
              return formatVal
            },
            optList: () => {
              return this.booleanOptions
            }
          },
          {
            minWidth: '140',
            prop: 'isUsed',
            label: '是否允许使用',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: (row, column, cellValue) => {
              var formatVal
              if (cellValue && cellValue == true) {
                formatVal = '<span>是</span>'
              } else if (cellValue == false) {
                formatVal = '<span style="color:red">否</span>'
              } else {
                formatVal = '<span></span>'
              }
              return formatVal
            },
            optList: () => {
              return this.booleanOptions
            }
          },
          {
            minWidth: '140',
            prop: 'remark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ]
      },
      booleanOptions: [
        { value: true, label: '是' },
        { value: false, label: '否' }
      ],
      checkStatusOptions: [
        { value: '01untested', label: '待检测' },
        { value: '02testing', label: '检测中' },
        { value: '03tested', label: '已检测' },
        { value: '04noTest', label: '不检测' }
      ]
    }
  },
  components: {
    ttable
  },
  methods: {
    saveSelectRow() {
      this.$emit('listenToproductionEvent', this.currentRow)
      this.innerVisible = false
    },
    handleCurrentChange(row) {
      this.currentRow = row
    },
    getData() {
      if (this.$refs.commonProductoutputTable !== undefined) {
        if (this.outBatchNo != null && this.outBatchNo !== '') {
          const queryParam = []
          queryParam.push(
            Object.assign({
              prop: 'outBatchNo',
              searchInfoType: 'text',
              propVal: this.outBatchNo
            })
          )
          this.$refs.commonProductoutputTable.setQueryParam(queryParam)
          this.$refs.commonProductoutputTable.getDataList()
        } else {
          this.$refs.commonProductoutputTable.cleanQueryParam()
        }
      }
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getData()
        })
      }
    }
  }
}
</script>
<style lang="scss" scoped>
.part-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.part-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.part-dialog .el-dialog__body {
  padding: 5px 20px;
}

.part-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.part-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
